# Security Policy

## Supported Versions

| Version | Supported          |
| ------- | ------------------ |
| 1.18 +  | :white_check_mark: |
| < 1.18  | :x:                |

## Reporting a Vulnerability

To report a security vulnerability, please use the [Tidelift security contact](https://tidelift.com/security). Tidelift
will coordinate the fix and disclosure.
